(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{28:function(e,t,a){e.exports=a(36)},36:function(e,t,a){"use strict";a.r(t);var r,n,i=a(6),c=a.n(i),o=a(27),s=a.n(o),l=a(24),d=a(0),p=a(1),m=a(2),u=a(3),b=a(20),g=a(21),h=a(15),f=function(e){Object(m.a)(a,e);var t=Object(u.a)(a);function a(){var e;Object(p.a)(this,a);for(var i=arguments.length,o=new Array(i),s=0;s<i;s++)o[s]=arguments[s];return(e=t.call.apply(t,[this].concat(o))).render=function(){b.a.setFrameHeight(window.innerHeight);var t=e.props.args,a=t.isUser,i=t.avatarStyle,o=t.seed,s=t.message,d="https://api.dicebear.com/5.x/".concat(i,"/svg?seed=").concat(o),p=e.props.theme;if(!p)return c.a.createElement("div",null,"Theme is undefined, please check streamlit version.");var m=g.a.img({border:"1px solid transparent",borderRadius:"50%",height:"3rem",width:"3rem",margin:0}),u=g.a.div({display:"inline-block",background:p.secondaryBackgroundColor,border:"1px solid transparent",borderRadius:"10px",padding:"10px 14px",margin:"5px 20px",maxWidth:"70%",whiteSpace:"pre-line"}),f=g.a.div({display:"flex",fontFamily:"".concat(p.font,", 'Segoe UI', 'Roboto', sans-serif"),height:"auto",margin:0,width:"100%"},(function(e){return e.isUser?Object(h.a)(r||(r=Object(l.a)(["\n          flex-direction: row-reverse;\n          & > div {\n            text-align: right;\n          }\n        "]))):Object(h.a)(n||(n=Object(l.a)([""])))}));return c.a.createElement(f,{isUser:a},c.a.createElement(m,{src:d,alt:"profile",draggable:"false"}),c.a.createElement(u,null,s))},e}return Object(d.a)(a)}(b.b),v=Object(b.c)(f);s.a.render(c.a.createElement(c.a.StrictMode,null,c.a.createElement(v,null)),document.getElementById("root"))}},[[28,1,2]]]);
//# sourceMappingURL=main.5efa2225.chunk.js.map